@@ -4,7 +4,7 @@ use warnings;
 
 package Path::Tiny;
 # ABSTRACT: File path utility
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 # Dependencies
 use autodie 2.14; # autodie::skip support
@@ -333,29 +333,32 @@ while ( my ( $k, $v ) = each %opens ) {
 # XXX this is ugly and coverage is incomplete.  I think it's there for windows
 # so need to check coverage there and compare
 sub parent {
-    my ($self) = @_;
+    my ($self, $level) = @_;
+    $level = 1 unless defined $level && $level > 0;
     $self->_splitpath unless defined $self->[FILE];
+    my $parent;
     if ( length $self->[FILE] ) {
         if ( $self->[FILE] eq '.' || $self->[FILE] =~ /\.\./ ) {
-            return path( $self->[PATH] . "/.." );
+            $parent = path( $self->[PATH] . "/.." );
         }
         else {
-            return path( _non_empty( $self->[VOL] . $self->[DIR] ) );
+            $parent = path( _non_empty( $self->[VOL] . $self->[DIR] ) );
         }
     }
     elsif ( length $self->[DIR] ) {
         if ( $self->[DIR] =~ /\.\./ ) {
-            return path( $self->[VOL] . $self->[DIR] . "/.." );
+            $parent = path( $self->[VOL] . $self->[DIR] . "/.." );
         }
         else {
-            return path("/") if $self->[DIR] eq "/";
+            $parent = path("/") if $self->[DIR] eq "/";
             ( my $dir = $self->[DIR] ) =~ s{/[^\/]+/$}{/};
-            return path( $self->[VOL] . $dir );
+            $parent = path( $self->[VOL] . $dir );
         }
     }
     else {
-        return path( _non_empty( $self->[VOL] ) );
+        $parent = path( _non_empty( $self->[VOL] ) );
     }
+    return $level == 1 ? $parent : $parent->parent( $level - 1 );
 }
 
 sub _non_empty {
@@ -506,7 +509,7 @@ Path::Tiny - File path utility
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -860,8 +863,12 @@ C<:raw:encoding(UTF-8)>, respectively.
     $parent = path("foo/bar/baz")->parent; # foo/bar
     $parent = path("foo/wibble.txt")->parent; # foo
 
-Returns a C<Path::Tiny> object corresponding to the parent
-directory of the original directory or file.
+    $parent = path("foo/bar/baz")->parent(2); # foo
+
+Returns a C<Path::Tiny> object corresponding to the parent directory of the
+original directory or file. An optional positive integer argument is the number
+of parent directories upwards to return.  C<parent> by itself is equivalent to
+C<parent(1)>.
 
 =head2 realpath
 
@@ -1099,6 +1106,24 @@ L<https://github.com/dagolden/path-tiny>
 
 David Golden <dagolden@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Chris 'BinGOs' Williams <chris@bingosnet.co.uk>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Michael G. Schwern <schwern@pobox.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2013 by David Golden.
